@@ -60,6 +60,8 @@ namespace freetrain.world.rail.tattc
         private Button buttonAllClear;
         private RadioButton radioRForwarding2;
         private RadioButton radioReverse2;
+        private RadioButton radioStopOnlyLoad;
+        private RadioButton radioStopForceUnload;
 
 		private readonly AdvancedStationHandler station;
 
@@ -146,6 +148,8 @@ namespace freetrain.world.rail.tattc
             this.buttonReadDia = new System.Windows.Forms.Button();
             this.buttonSaveDia = new System.Windows.Forms.Button();
             this.buttonAllClear = new System.Windows.Forms.Button();
+            this.radioStopForceUnload = new System.Windows.Forms.RadioButton();
+            this.radioStopOnlyLoad = new System.Windows.Forms.RadioButton();
             this.groupBox1.SuspendLayout();
             this.SuspendLayout();
             // 
@@ -153,6 +157,8 @@ namespace freetrain.world.rail.tattc
             // 
             this.groupBox1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                         | System.Windows.Forms.AnchorStyles.Right)));
+            this.groupBox1.Controls.Add(this.radioStopOnlyLoad);
+            this.groupBox1.Controls.Add(this.radioStopForceUnload);
             this.groupBox1.Controls.Add(this.radioRForwarding2);
             this.groupBox1.Controls.Add(this.radioReverse2);
             this.groupBox1.Controls.Add(this.radioRForwarding);
@@ -175,7 +181,7 @@ namespace freetrain.world.rail.tattc
             this.groupBox1.Controls.Add(this.label1);
             this.groupBox1.Location = new System.Drawing.Point(0, 8);
             this.groupBox1.Name = "groupBox1";
-            this.groupBox1.Size = new System.Drawing.Size(590, 80);
+            this.groupBox1.Size = new System.Drawing.Size(679, 80);
             this.groupBox1.TabIndex = 0;
             this.groupBox1.TabStop = false;
             this.groupBox1.Text = "";
@@ -183,7 +189,7 @@ namespace freetrain.world.rail.tattc
             // radioRForwarding2
             // 
             this.radioRForwarding2.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
-            this.radioRForwarding2.Location = new System.Drawing.Point(360, 38);
+            this.radioRForwarding2.Location = new System.Drawing.Point(472, 38);
             this.radioRForwarding2.Name = "radioRForwarding2";
             this.radioRForwarding2.Size = new System.Drawing.Size(52, 38);
             this.radioRForwarding2.TabIndex = 19;
@@ -193,7 +199,7 @@ namespace freetrain.world.rail.tattc
             // radioReverse2
             // 
             this.radioReverse2.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
-            this.radioReverse2.Location = new System.Drawing.Point(193, 38);
+            this.radioReverse2.Location = new System.Drawing.Point(305, 38);
             this.radioReverse2.Name = "radioReverse2";
             this.radioReverse2.Size = new System.Drawing.Size(52, 38);
             this.radioReverse2.TabIndex = 18;
@@ -203,7 +209,7 @@ namespace freetrain.world.rail.tattc
             // radioRForwarding
             // 
             this.radioRForwarding.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
-            this.radioRForwarding.Location = new System.Drawing.Point(301, 38);
+            this.radioRForwarding.Location = new System.Drawing.Point(413, 38);
             this.radioRForwarding.Name = "radioRForwarding";
             this.radioRForwarding.Size = new System.Drawing.Size(52, 38);
             this.radioRForwarding.TabIndex = 15;
@@ -213,7 +219,7 @@ namespace freetrain.world.rail.tattc
             // radioForwarding
             // 
             this.radioForwarding.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
-            this.radioForwarding.Location = new System.Drawing.Point(260, 38);
+            this.radioForwarding.Location = new System.Drawing.Point(372, 38);
             this.radioForwarding.Name = "radioForwarding";
             this.radioForwarding.Size = new System.Drawing.Size(40, 38);
             this.radioForwarding.TabIndex = 14;
@@ -223,7 +229,7 @@ namespace freetrain.world.rail.tattc
             // radioReverse
             // 
             this.radioReverse.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
-            this.radioReverse.Location = new System.Drawing.Point(136, 38);
+            this.radioReverse.Location = new System.Drawing.Point(248, 38);
             this.radioReverse.Name = "radioReverse";
             this.radioReverse.Size = new System.Drawing.Size(52, 38);
             this.radioReverse.TabIndex = 13;
@@ -242,7 +248,7 @@ namespace freetrain.world.rail.tattc
             "30",
             "40",
             "50"});
-            this.minBox.Location = new System.Drawing.Point(493, 16);
+            this.minBox.Location = new System.Drawing.Point(582, 16);
             this.minBox.MaxDropDownItems = 13;
             this.minBox.Name = "minBox";
             this.minBox.Size = new System.Drawing.Size(57, 20);
@@ -251,7 +257,7 @@ namespace freetrain.world.rail.tattc
             // radioGo
             // 
             this.radioGo.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
-            this.radioGo.Location = new System.Drawing.Point(96, 38);
+            this.radioGo.Location = new System.Drawing.Point(208, 38);
             this.radioGo.Name = "radioGo";
             this.radioGo.Size = new System.Drawing.Size(40, 38);
             this.radioGo.TabIndex = 12;
@@ -283,7 +289,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonReplace.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonReplace.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonReplace.Location = new System.Drawing.Point(517, 48);
+            this.buttonReplace.Location = new System.Drawing.Point(606, 48);
             this.buttonReplace.Name = "buttonReplace";
             this.buttonReplace.Size = new System.Drawing.Size(64, 24);
             this.buttonReplace.TabIndex = 17;
@@ -320,7 +326,7 @@ namespace freetrain.world.rail.tattc
             "21",
             "22",
             "23"});
-            this.hourBox.Location = new System.Drawing.Point(413, 16);
+            this.hourBox.Location = new System.Drawing.Point(502, 16);
             this.hourBox.MaxDropDownItems = 13;
             this.hourBox.Name = "hourBox";
             this.hourBox.Size = new System.Drawing.Size(57, 20);
@@ -339,7 +345,7 @@ namespace freetrain.world.rail.tattc
             "",
             "",
             "y"});
-            this.dayOfWeekBox.Location = new System.Drawing.Point(317, 16);
+            this.dayOfWeekBox.Location = new System.Drawing.Point(406, 16);
             this.dayOfWeekBox.MaxDropDownItems = 13;
             this.dayOfWeekBox.Name = "dayOfWeekBox";
             this.dayOfWeekBox.Size = new System.Drawing.Size(56, 20);
@@ -382,7 +388,7 @@ namespace freetrain.world.rail.tattc
             "29",
             "30",
             "31"});
-            this.dayBox.Location = new System.Drawing.Point(237, 16);
+            this.dayBox.Location = new System.Drawing.Point(326, 16);
             this.dayBox.MaxDropDownItems = 13;
             this.dayBox.Name = "dayBox";
             this.dayBox.Size = new System.Drawing.Size(56, 20);
@@ -406,7 +412,7 @@ namespace freetrain.world.rail.tattc
             "10",
             "11",
             "12"});
-            this.monthBox.Location = new System.Drawing.Point(157, 16);
+            this.monthBox.Location = new System.Drawing.Point(246, 16);
             this.monthBox.MaxDropDownItems = 13;
             this.monthBox.Name = "monthBox";
             this.monthBox.Size = new System.Drawing.Size(56, 20);
@@ -416,7 +422,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonAdd.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonAdd.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonAdd.Location = new System.Drawing.Point(446, 48);
+            this.buttonAdd.Location = new System.Drawing.Point(535, 48);
             this.buttonAdd.Name = "buttonAdd";
             this.buttonAdd.Size = new System.Drawing.Size(64, 24);
             this.buttonAdd.TabIndex = 16;
@@ -427,7 +433,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.label5.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.label5.BackColor = System.Drawing.Color.Transparent;
-            this.label5.Location = new System.Drawing.Point(557, 16);
+            this.label5.Location = new System.Drawing.Point(646, 16);
             this.label5.Name = "label5";
             this.label5.Size = new System.Drawing.Size(24, 20);
             this.label5.TabIndex = 9;
@@ -438,7 +444,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.label4.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.label4.BackColor = System.Drawing.Color.Transparent;
-            this.label4.Location = new System.Drawing.Point(477, 16);
+            this.label4.Location = new System.Drawing.Point(566, 16);
             this.label4.Name = "label4";
             this.label4.Size = new System.Drawing.Size(24, 20);
             this.label4.TabIndex = 7;
@@ -449,7 +455,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.label3.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.label3.BackColor = System.Drawing.Color.Transparent;
-            this.label3.Location = new System.Drawing.Point(381, 16);
+            this.label3.Location = new System.Drawing.Point(470, 16);
             this.label3.Name = "label3";
             this.label3.Size = new System.Drawing.Size(40, 20);
             this.label3.TabIndex = 5;
@@ -460,7 +466,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.label2.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.label2.BackColor = System.Drawing.Color.Transparent;
-            this.label2.Location = new System.Drawing.Point(301, 16);
+            this.label2.Location = new System.Drawing.Point(390, 16);
             this.label2.Name = "label2";
             this.label2.Size = new System.Drawing.Size(25, 20);
             this.label2.TabIndex = 3;
@@ -471,7 +477,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.label1.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.label1.BackColor = System.Drawing.Color.Transparent;
-            this.label1.Location = new System.Drawing.Point(221, 16);
+            this.label1.Location = new System.Drawing.Point(310, 16);
             this.label1.Name = "label1";
             this.label1.Size = new System.Drawing.Size(25, 20);
             this.label1.TabIndex = 1;
@@ -482,7 +488,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonUp.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonUp.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonUp.Location = new System.Drawing.Point(517, 96);
+            this.buttonUp.Location = new System.Drawing.Point(606, 96);
             this.buttonUp.Name = "buttonUp";
             this.buttonUp.Size = new System.Drawing.Size(64, 24);
             this.buttonUp.TabIndex = 19;
@@ -493,7 +499,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonDown.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonDown.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonDown.Location = new System.Drawing.Point(517, 128);
+            this.buttonDown.Location = new System.Drawing.Point(606, 128);
             this.buttonDown.Name = "buttonDown";
             this.buttonDown.Size = new System.Drawing.Size(64, 24);
             this.buttonDown.TabIndex = 20;
@@ -504,7 +510,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonRemove.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonRemove.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonRemove.Location = new System.Drawing.Point(517, 186);
+            this.buttonRemove.Location = new System.Drawing.Point(606, 186);
             this.buttonRemove.Name = "buttonRemove";
             this.buttonRemove.Size = new System.Drawing.Size(64, 24);
             this.buttonRemove.TabIndex = 22;
@@ -516,7 +522,7 @@ namespace freetrain.world.rail.tattc
             this.buttonOk.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonOk.DialogResult = System.Windows.Forms.DialogResult.OK;
             this.buttonOk.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonOk.Location = new System.Drawing.Point(493, 336);
+            this.buttonOk.Location = new System.Drawing.Point(582, 336);
             this.buttonOk.Name = "buttonOk";
             this.buttonOk.Size = new System.Drawing.Size(88, 24);
             this.buttonOk.TabIndex = 23;
@@ -540,7 +546,7 @@ namespace freetrain.world.rail.tattc
             this.triggerList.Location = new System.Drawing.Point(8, 96);
             this.triggerList.MultiSelect = false;
             this.triggerList.Name = "triggerList";
-            this.triggerList.Size = new System.Drawing.Size(493, 232);
+            this.triggerList.Size = new System.Drawing.Size(582, 232);
             this.triggerList.Sorting = System.Windows.Forms.SortOrder.Ascending;
             this.triggerList.TabIndex = 18;
             this.triggerList.UseCompatibleStateImageBehavior = false;
@@ -575,7 +581,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonCopy.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonCopy.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonCopy.Location = new System.Drawing.Point(517, 157);
+            this.buttonCopy.Location = new System.Drawing.Point(606, 157);
             this.buttonCopy.Name = "buttonCopy";
             this.buttonCopy.Size = new System.Drawing.Size(64, 24);
             this.buttonCopy.TabIndex = 21;
@@ -586,7 +592,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonReadDia.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonReadDia.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonReadDia.Location = new System.Drawing.Point(149, 336);
+            this.buttonReadDia.Location = new System.Drawing.Point(238, 336);
             this.buttonReadDia.Name = "buttonReadDia";
             this.buttonReadDia.Size = new System.Drawing.Size(88, 24);
             this.buttonReadDia.TabIndex = 24;
@@ -597,7 +603,7 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonSaveDia.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonSaveDia.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonSaveDia.Location = new System.Drawing.Point(241, 336);
+            this.buttonSaveDia.Location = new System.Drawing.Point(330, 336);
             this.buttonSaveDia.Name = "buttonSaveDia";
             this.buttonSaveDia.Size = new System.Drawing.Size(89, 24);
             this.buttonSaveDia.TabIndex = 25;
@@ -608,18 +614,38 @@ namespace freetrain.world.rail.tattc
             // 
             this.buttonAllClear.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
             this.buttonAllClear.FlatStyle = System.Windows.Forms.FlatStyle.System;
-            this.buttonAllClear.Location = new System.Drawing.Point(517, 214);
+            this.buttonAllClear.Location = new System.Drawing.Point(606, 214);
             this.buttonAllClear.Name = "buttonAllClear";
             this.buttonAllClear.Size = new System.Drawing.Size(64, 24);
             this.buttonAllClear.TabIndex = 26;
             this.buttonAllClear.Text = "Sď";
             this.buttonAllClear.Click += new System.EventHandler(this.buttonAllClear_Click);
             // 
+            // radioStopForceUnload
+            // 
+            this.radioStopForceUnload.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
+            this.radioStopForceUnload.Location = new System.Drawing.Point(100, 38);
+            this.radioStopForceUnload.Name = "radioStopForceUnload";
+            this.radioStopForceUnload.Size = new System.Drawing.Size(48, 38);
+            this.radioStopForceUnload.TabIndex = 20;
+            this.radioStopForceUnload.Text = "S";
+            this.radioStopForceUnload.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
+            // 
+            // radioStopOnlyLoad
+            // 
+            this.radioStopOnlyLoad.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
+            this.radioStopOnlyLoad.Location = new System.Drawing.Point(154, 38);
+            this.radioStopOnlyLoad.Name = "radioStopOnlyLoad";
+            this.radioStopOnlyLoad.Size = new System.Drawing.Size(48, 38);
+            this.radioStopOnlyLoad.TabIndex = 27;
+            this.radioStopOnlyLoad.Text = "ԂȂ";
+            this.radioStopOnlyLoad.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
+            // 
             // StationAdvancedDialog
             // 
             this.AcceptButton = this.buttonOk;
             this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
-            this.ClientSize = new System.Drawing.Size(590, 365);
+            this.ClientSize = new System.Drawing.Size(679, 365);
             this.Controls.Add(this.buttonAllClear);
             this.Controls.Add(this.buttonSaveDia);
             this.Controls.Add(this.buttonReadDia);
@@ -872,6 +898,9 @@ namespace freetrain.world.rail.tattc
             }
 #endregion
 
+            if( radioStopForceUnload.Checked )		tm.action = StationAction.stopForceUnload;
+			if( radioStopOnlyLoad.Checked )		tm.action = StationAction.stopOnlyLoad;
+
             return tm;
 		}
 
@@ -906,6 +935,9 @@ namespace freetrain.world.rail.tattc
 			case StationAction.reverse2:	return "]ܕ";
 			case StationAction.rforwarding2:	return "]";
 
+			case StationAction.stopForceUnload:	return "S";
+			case StationAction.stopOnlyLoad:	return "ԂȂ";
+              
 			default:
 				Debug.Assert(false);
 				return null;
@@ -959,6 +991,8 @@ namespace freetrain.world.rail.tattc
 				radioReverse2.Checked = (rule.action==StationAction.reverse2);
 			    radioRForwarding2.Checked = (rule.action == StationAction.rforwarding2);
 
+				radioStopForceUnload.Checked	= (rule.action==StationAction.stopForceUnload);
+				radioStopOnlyLoad.Checked	= (rule.action==StationAction.stopOnlyLoad);
 			}
 		}
 	}
